##  Subscription Settings
You can customize and manage various settings related to subscriptions. These settings include enabling the subscription type 'Accountable', controlling whether users can have multiple subscriptions for a single fact sheet, enforcing mandatory selection of a subscription role when subscribing to a fact sheet, and adjusting the data privacy level for subscriptions.
![Managing Subscription Types in Settings](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27556a887a4410149222a1438337803d_LowRes.png)
Subscription Settings
